@@ -68,7 +68,11 @@ class PDFAQuantizationNAryTreeLearner:
         self._teacher = teacher
         models = []
         is_target_DFA, model = self.initialization(verbose)
+        symbols = list(self._alphabet.symbols)
         if not is_target_DFA:
+            for symbol in symbols:
+                self._tree.sift(Sequence([symbol]))
+            
             model = self.tentative_hypothesis()
             models.append(model)
             last_size = len(model.weighted_states)
@@ -89,10 +93,11 @@ class PDFAQuantizationNAryTreeLearner:
         result = self._learning_results_for(model)
         return result
 
-    def _learning_results_for(self, model):
+    def _learning_results_for(self, model, rename_states = False):
         numberOfStates = len(model.weighted_states) if model is not None else 0
-        for count, state in enumerate(model.weighted_states):
-            state.name = 'q' + str(count)
+        if rename_states:
+            for count, state in enumerate(model.weighted_states):
+                state.name = 'q' + str(count)
 
         info = {
             'equivalence_queries_count': self._teacher.equivalence_queries_count,
