@@ -33,7 +33,7 @@ class PACBatchProbabilisticTeacher(PACProbabilisticTeacher):
             word = rand_words[i]
             obs1 = results[i]
             obs2 = aut.get_last_token_weights(word, suffixes)
-            if not self._comparator.equivalent_output(obs1, obs2):
+            if not self._comparator.next_tokens_equivalent_output(obs1, obs2):
                 errorCount += 1
                 if counterexample is None:
                     counterexample = word
