@@ -8,6 +8,8 @@ from pymodelextractor.learners.observation_tree_learners.bounded_pdfa_quantizati
 from pythautomata.model_comparators.wfa_tolerance_comparison_strategy import WFAToleranceComparator
 from pythautomata.model_comparators.wfa_quantization_comparison_strategy import WFAQuantizationComparator
 from pythautomata.utilities.probability_partitioner import QuantizationProbabilityPartitioner
+from pythautomata.model_comparators.wfa_partition_comparison_strategy import WFAPartitionComparator
+from pythautomata.utilities.probability_partitioner import QuantizationProbabilityPartitioner, TopKProbabilityPartitioner
 
 from pymodelextractor.teachers.pdfa_teacher import PDFATeacher
 
@@ -24,9 +26,9 @@ binaryAlphabet = Alphabet(frozenset((SymbolStr('0'), SymbolStr('1'))))
 class TestBoundedPDFAQuantizantionNAryTreeLearner(unittest.TestCase):
 
     def setUp(self):
-        self.partitions = 10
-        self.comparator = WFAQuantizationComparator(self.partitions)
+        self.partitions = 10        
         self.partitioner = QuantizationProbabilityPartitioner(self.partitions)
+        self.comparator = WFAPartitionComparator(self.partitioner)
         self.learner = BoundedPDFAQuantizationNAryTreeLearner(self.partitioner,max_states= 100, max_query_length=100)
 
     def test_time_bound(self):
@@ -338,4 +340,70 @@ class TestBoundedPDFAQuantizantionNAryTreeLearner(unittest.TestCase):
         extracted_model = result.model
         self.assertNotEqual(model, extracted_model)
         self.assertTrue(result.info['last_token_weight_queries_count'] > 0)
+        self.assertTrue(result.info['equivalence_queries_count'] > 0)
+
+    
+    def generate_PDFA_with_3_equivalent_states_according_to_argmax(self):
+        
+        qeps = WeightedState("qeps", 1, 0.60296)
+        q1 = WeightedState("q0", 0, 0.56036)
+        q11 = WeightedState("q1", 0, 0.50998)
+
+        zero = SymbolStr('0')
+        one = SymbolStr('1')
+        qeps.add_transition(zero, qeps, 0.12317)
+        qeps.add_transition(one, q1, 0.27387)
+        q1.add_transition(zero, q1, 0.20647)
+        q1.add_transition(one, q11, 0.23317)
+        q11.add_transition(zero, q11, 0.25791)
+        q11.add_transition(one, q11, 0.23211)        
+        
+
+        states = {qeps, q1, q11}
+        comparator = WFAToleranceComparator()
+        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), comparator,
+                                                         "PDFA_with_3_equivalent_states_according_to_argmax")
+    
+    def generate_PDFA_with_3_different_states_according_to_argmax(self):
+        
+        qeps = WeightedState("qeps", 1, 0.6)
+        q1 = WeightedState("q0", 0, 0.2)
+        q11 = WeightedState("q1", 0, 0.2)
+
+        zero = SymbolStr('0')
+        one = SymbolStr('1')
+        qeps.add_transition(zero, qeps, 0.2)
+        qeps.add_transition(one, q1, 0.2)
+        q1.add_transition(zero, q1, 0.6)
+        q1.add_transition(one, q11, 0.2)
+        q11.add_transition(zero, q11, 0.2)
+        q11.add_transition(one, q11, 0.6)      
+        states = {qeps, q1, q11}
+        comparator = WFAToleranceComparator()
+        return ProbabilisticDeterministicFiniteAutomaton(binaryAlphabet, states, SymbolStr("$"), comparator,
+                                                         "PDFA_with_3_equivalent_states_according_to_argmax")
+    
+
+    def test_arg_max_partitioner1(self):     
+        model = self.generate_PDFA_with_3_equivalent_states_according_to_argmax()
+        partitioner = TopKProbabilityPartitioner(1)
+        comparator = WFAPartitionComparator(partitioner)
+        teacher = PDFATeacher(model, comparator)
+        learner = BoundedPDFAQuantizationNAryTreeLearner(partitioner,10, 30)
+        result = learner.learn(teacher)
+        extracted_model = result.model
+        self.assertTrue(len(extracted_model.weighted_states) == 1)
+        self.assertTrue(result.info['last_token_weight_queries_count'] > 0)        
+        self.assertTrue(result.info['equivalence_queries_count'] > 0)
+
+    
+    def test_arg_max_partitioner2(self):     
+        model = self.generate_PDFA_with_3_different_states_according_to_argmax()
+        partitioner = TopKProbabilityPartitioner(1)
+        comparator = WFAPartitionComparator(partitioner)
+        teacher = PDFATeacher(model, comparator)
+        learner = BoundedPDFAQuantizationNAryTreeLearner(partitioner,10, 2, generate_partial_hipothesis=True)
+        result = learner.learn(teacher)
+        extracted_model = result.model
+        self.assertTrue(result.info['last_token_weight_queries_count'] > 0)        
         self.assertTrue(result.info['equivalence_queries_count'] > 0)
\ No newline at end of file
